@@ -3,7 +3,7 @@ BEGIN {
   $MooseX::Declare::Syntax::Keyword::MethodModifier::AUTHORITY = 'cpan:FLORA';
 }
 {
-  $MooseX::Declare::Syntax::Keyword::MethodModifier::VERSION = '0.35';
+  $MooseX::Declare::Syntax::Keyword::MethodModifier::VERSION = '0.36';
 }
 # ABSTRACT: Handle method modifier declarations
 
@@ -19,7 +19,7 @@ with 'MooseX::Declare::Syntax::MethodDeclaration';
 
 has modifier_type => (
     is          => 'rw',
-    isa         => enum(undef, qw( around after before override augment )),
+    isa         => enum([qw( around after before override augment )]),
     required    => 1,
 );
 
@@ -33,6 +33,7 @@ sub register_method_declaration {
 1;
 
 __END__
+
 =pod
 
 =encoding utf-8
@@ -198,10 +199,9 @@ Yanick Champoux <yanick@babyl.dyndns.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Florian Ragwitz.
+This software is copyright (c) 2013 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
